﻿//Apple Pay operations object
var applePayObj = {
    //Payment methods
    payment: {
        beginPayment: function (e) {
            e.preventDefault();

            if (applePayPaymentData == undefined || applePayPaymentData == null) {
                alert("No Apple Pay payment data defined.");
                return;
            }

            //TODO: This reads the country and currency code from META CONTENT tags that can be generated
            //with the Oshyn.Episerver.Addons.Commerce.ApplePay.Helpers.ApplePayHtmlHelpers.RenderApplePayMetaTags() helper method.
            //You might want to change the location of these declarations in your code, but make sure they are
            //accessible from this method.
            var countryCode = document.querySelector("meta[name='payment-country-code']").getAttribute("content");
            var currencyCode = document.querySelector("meta[name='payment-currency-code']").getAttribute("content");

            //TODO: Change this object to your specific payment requirements. Refer to Apple Pay documentation for details.
            //Please note that you will require to include the lineItems and total fields. You will need to generate
            //these from the data on Episerver Commerce during checkout.
            var applePayPaymentData = {
                countryCode: countryCode,
                currencyCode: currencyCode,
                merchantCapabilities: ["supports3DS"],
                supportedNetworks: ["visa", "masterCard", "amex", "discover", "jcb"]
            };

            var session = new ApplePaySession(2, applePayPaymentData);

            //Define the merchant validation event. This event should call the MVC action in the .NET web app to perform the server side validation.
            session.onvalidatemerchant = function (event) {
                var data = {
                    ValidationUrl: event.validationURL
                };

                $.ajax({
                    url: "/ApplePay/StartPaySession",
                    method: "POST",
                    contentType: "application/json; charset=utf-8",
                    data: JSON.stringify(data)
                }).then(function (merchantSession) {
                    session.completeMerchantValidation(merchantSession);
                }, function (error) {
                    console.log(error);
                    session.abort();
                    paymentObject.applePay.showError("Failed to validate merchant. " + error.responseText);
                });
            };

            //Logic to follow after the user authorizes the payment.
            session.onpaymentauthorized = function (event) {
                //TODO: Perform your post-payment authorization logic here, such as calling the Episerver Commerce back-end
                //payment gateway to process the payment. Make sure to complete the payment with one of the codes as
                //described on Apple Pay's documentation using the session.completePayment() method.
                session.completePayment(ApplePaySession.STATUS_SUCCESS);
            }

            //Starts the Apple Pay session by showing 
            session.begin();
        }
    },
    //Setup methods
    setup: {
        //Sets up Apple Pay in the current device.
        setupApplePay: function (merchantIdentifier) {
            ApplePaySession.openPaymentSetup(merchantIdentifier)
                .then(function (success) {
                    if (success) {
                        applePayObj.setup.hideSetupButton();
                        applePayObj.setup.showButton();
                    } else {
                        applePayObj.page.showError("Failed to set up Apple Pay.");
                    }
                }).catch(function (e) {
                    applePayObj.page.showError("Failed to set up Apple Pay. " + e);
                });
        },
        //Shows the Apple Pay button.
        showButton: function () {
            var button = $("#apple-pay-button");
            button.attr("lang", applePayObj.page.getPageLanguage());
            button.on("click", applePayObj.payment.beginPayment);

            if (applePayObj.setup.supportsSetup()) {
                button.addClass("apple-pay-button-with-text");
                button.addClass("apple-pay-button-black-with-text");
            } else {
                button.addClass("apple-pay-button");
                button.addClass("apple-pay-button-black");
            }

            button.removeClass("hide");
        },
        hideAllButtons: function () {
            var payButton = $("#apple-pay-button");
            var setupButton = $("#set-up-apple-pay-button");

            payButton.addClass("hide");
            setupButton.addClass("hide");
        },
        //Shows the Set Up Apple Pay button
        showSetupButton: function () {
            var button = $("#set-up-apple-pay-button");
            button.attr("lang", applePayObj.page.getPageLanguage());
            button.attr("click", applePayObj.setup.setupApplePay);
            button.removeClass("hide");
        },
        //Hides the Set Up Apple Pay button
        hideSetupButton: function () {
            var button = $("#set-up-apple-pay-button");
            button.addClass("hide");
            button.off("click");
        },
        
        //Returns true if the current browser and device supports Apple Pay on the Web
        supportedByDevice: function () {
            return "ApplePaySession" in window;
        },
        //Returns true if the current browser and device supports setting up Apple Pay
        supportsSetup: function () {
            return "openPaymentSetup" in ApplePaySession;
        }
    },
    //Page methods
    page: {
        //Gets the page language from the lang attribute in the main html tag
        getPageLanguage: function () {
            return $("html").attr("lang") || "en";
        },
        //Method to show errors
        showError: function (text) {
            var error = $(".apple-pay-error");
            error.text(text);
            error.removeClass("hide");
        },
        //Shows the payment successful panel
        showSuccess: function (text) {
            $(".apple-pay-intro").hide();
            var success = $(".apple-pay-success");
            success.removeClass("hide");
        }
    }
};